SCB Import
==========

Tools for using the SCB open data API.

Developed on Linux and is work in progress.

**References**

- Swedish - `SCB:s statistik tillgänglig via API <https://www.scb.se/om-scb/om-scb.se-och-anvandningsvillkor/oppna-data-api/>`_
- English - `Statistics Sweden is statistics accessible via API <https://www.scb.se/en/About-us/about-the-website-and-terms-of-use/open-data-api/>`_
